/***********************************************************************************************
/	Copyright 2006	by Taco Cohen. All rights reserved							
/***********************************************************************************************/

/***********************************************************************************************
/	 Ambient Lighting Shader
/
/		OUTLINE:
/	This shader draws the object in a solid color given by the materials ambient color.
/	
/		IMPLEMENTATION:
/	The vertex shader transforms the vertex to clip space. The pixel shader multiplies the
/	ambient color by the ambient intensity and returns that as the final pixel color.
/
/		NOTES:
/	-
/***********************************************************************************************/

/***********************************************************************************************
/	Global Variables:
/***********************************************************************************************/
// Tweakables:
static const float AmbientIntensity	= 1.0f;					// The intensity of the ambient light.

// Application fed data:
const float4x4 matWorldViewProj;	// World*view*projection matrix.
const float4 vecAmbient;			// Ambient color, passed by the engine.

/***********************************************************************************************
/	Vertex Shader:
/***********************************************************************************************/
void AmbientVS(	in float4 InPos		: POSITION,
				out float4 OutPos	: POSITION)
{
	// Transform the vertex from object space to clip space:
	OutPos = mul(InPos, matWorldViewProj);
}

/***********************************************************************************************
/	Pixel Shader:
/***********************************************************************************************/
float4 AmbientPS() : COLOR
{
	return AmbientIntensity * vecAmbient;
}

/***********************************************************************************************
/	Technique:
/***********************************************************************************************/
technique AmbientTechnique
{
	pass P0
	{
		VertexShader = compile vs_1_1 AmbientVS();
		PixelShader  = compile ps_1_1 AmbientPS();
	}
}